@@ -3,7 +3,7 @@ from shapely import geometry as sg
 
 from sepal_ui import sepalwidgets as sw
 from sepal_ui.mapping.menu_control import MenuControl
-from sepal_ui.scripts import utils as su
+from sepal_ui.scripts import decorator as sd
 
 
 class AoiControl(MenuControl):
@@ -36,7 +36,7 @@ class AoiControl(MenuControl):
         self.aoi_list = sw.ListItemGroup(children=[], v_model="")
 
         # create the widget
-        super().__init__("fas fa-search-location", self.aoi_list, **kwargs)
+        super().__init__("fa-solid fa-search-location", self.aoi_list, **kwargs)
 
         # change a bit the behavior of the control
         self.menu.open_on_hover = True
@@ -70,7 +70,7 @@ class AoiControl(MenuControl):
 
         return
 
-    @su.need_ee
+    @sd.need_ee
     def add_aoi(self, name, item):
         """
         Add an AOI to the list and refresh the list displayed. the AOI will be composed of a name and the bounds of the provided item.
