@@ -27,14 +27,16 @@ from matplotlib import colorbar
 from matplotlib import colors as mpc
 from rasterio.crs import CRS
 
-from sepal_ui import color
+from sepal_ui import color as scolors
 from sepal_ui.frontend import styles as ss
 from sepal_ui.mapping.basemaps import basemap_tiles
 from sepal_ui.mapping.draw_control import DrawControl
 from sepal_ui.mapping.layer import EELayer
 from sepal_ui.mapping.layer_state_control import LayerStateControl
+from sepal_ui.mapping.legend_control import LegendControl
 from sepal_ui.mapping.value_inspector import ValueInspector
 from sepal_ui.message import ms
+from sepal_ui.scripts import decorator as sd
 from sepal_ui.scripts import utils as su
 from sepal_ui.scripts.warning import SepalWarning
 
@@ -107,7 +109,7 @@ class SepalMap(ipl.Map):
         not gee or su.init_ee()
 
         # add the basemaps
-        self.clear_layers()
+        self.clear()
         default_basemap = (
             "CartoDB.DarkMatter" if v.theme.dark is True else "CartoDB.Positron"
         )
@@ -115,22 +117,22 @@ class SepalMap(ipl.Map):
         [self.add_basemap(basemap) for basemap in set(basemaps)]
 
         # add the base controls
-        self.add_control(ipl.ZoomControl(position="topright"))
-        self.add_control(ipl.LayersControl(position="topright"))
-        self.add_control(ipl.AttributionControl(position="bottomleft", prefix="SEPAL"))
-        self.add_control(ipl.ScaleControl(position="bottomleft", imperial=False))
+        self.add(ipl.ZoomControl(position="topright"))
+        self.add(ipl.LayersControl(position="topright"))
+        self.add(ipl.AttributionControl(position="bottomleft", prefix="SEPAL"))
+        self.add(ipl.ScaleControl(position="bottomleft", imperial=False))
 
         # specific drawing control
         self.dc = DrawControl(self)
-        not dc or self.add_control(self.dc)
+        not dc or self.add(self.dc)
 
         # specific v_inspector
         self.v_inspector = ValueInspector(self)
-        not vinspector or self.add_control(self.v_inspector)
+        not vinspector or self.add(self.v_inspector)
 
         # specific statebar
         self.state = LayerStateControl(self)
-        not statebar or self.add_control(self.state)
+        not statebar or self.add(self.state)
 
         # create a proxy ID to the element
         # this id should be unique and will be used by mutators to identify this map
@@ -185,7 +187,7 @@ class SepalMap(ipl.Map):
 
         return
 
-    @su.need_ee
+    @sd.need_ee
     def zoom_ee_object(self, item, zoom_out=1):
         """
         Get the proper zoom to the given ee geometry.
@@ -464,7 +466,7 @@ class SepalMap(ipl.Map):
             output.clear_output()
             plt.show()
 
-        self.add_control(colormap_ctrl)
+        self.add(colormap_ctrl)
 
         return
 
@@ -492,16 +494,32 @@ class SepalMap(ipl.Map):
             viz_name (str, optional): the name of the vizaulization you want ot use. default to the first one if existing
         """
 
+        # check the type of the ee object and raise an error if it's not recognized
+        if not isinstance(
+            ee_object,
+            (
+                ee.Image,
+                ee.ImageCollection,
+                ee.FeatureCollection,
+                ee.Feature,
+                ee.Geometry,
+            ),
+        ):
+            raise AttributeError(
+                "\n\nThe image argument in 'addLayer' function must be an instance of "
+                "one of ee.Image, ee.Geometry, ee.Feature or ee.FeatureCollection."
+            )
+
         # get the list of viz params
         viz = self.get_viz_params(ee_object)
 
         # get the requested vizparameters name
         # if non is set use the first one
-        if not viz == {}:
+        if viz:
             viz_name = viz_name or viz[next(iter(viz))]["name"]
 
         # apply it to vis_params
-        if vis_params == {} and viz != {}:
+        if not vis_params and viz:
 
             # find the viz params in the list
             try:
@@ -584,22 +602,6 @@ class SepalMap(ipl.Map):
             layer_count = len(self.layers)
             name = "Layer " + str(layer_count + 1)
 
-        # check the type of the ee object and raise an error if it's not recognized
-        if not isinstance(
-            ee_object,
-            (
-                ee.Image,
-                ee.ImageCollection,
-                ee.FeatureCollection,
-                ee.Feature,
-                ee.Geometry,
-            ),
-        ):
-            raise AttributeError(
-                "\n\nThe image argument in 'addLayer' function must be an instance of "
-                "one of ee.Image, ee.Geometry, ee.Feature or ee.FeatureCollection."
-            )
-
         # force cast to featureCollection if needed
         if isinstance(
             ee_object,
@@ -609,17 +611,31 @@ class SepalMap(ipl.Map):
                 ee.featurecollection.FeatureCollection,
             ),
         ):
+            default_vis = json.loads((ss.JSON_DIR / "layer.json").read_text())[
+                "ee_layer"
+            ]
+            default_vis.update(color=scolors.primary)
+
+            # We want to get all the default styles and only change those whose are
+            # in the provided visualization.
+            default_vis.update(vis_params)
+
+            vis_params = default_vis
 
             features = ee.FeatureCollection(ee_object)
-
-            width = vis_params.pop("width", 2)
-            color = vis_params.pop("color", "000000")
-
             const_image = ee.Image.constant(0.5)
-            image_fill = features.style(fillColor=color).updateMask(const_image)
-            image_outline = features.style(
-                color=color, fillColor="00000000", width=width
-            )
+
+            try:
+                image_fill = features.style(**vis_params).updateMask(const_image)
+                image_outline = features.style(**vis_params)
+
+            except AttributeError:
+                # Raise a more understandable error
+                raise AttributeError(
+                    "You can only use the following styles: 'color', 'pointSize', "
+                    "'pointShape', 'width', 'fillColor', 'styleProperty', "
+                    "'neighborhood', 'lineType'"
+                )
 
             image = image_fill.blend(image_outline)
             obj = features
@@ -748,7 +764,7 @@ class SepalMap(ipl.Map):
 
         # the error is catched in find_layer
         if layer is not None:
-            super().remove_layer(layer)
+            super().remove(layer)
 
         return
 
@@ -785,19 +801,21 @@ class SepalMap(ipl.Map):
         if isinstance(layer, ipl.GeoJSON):
 
             # define the default values
-            default_style = json.loads((ss.JSON_DIR / "layer.json").read_text())
-            default_style.update(color=color.primary)
+            default_style = json.loads((ss.JSON_DIR / "layer.json").read_text())[
+                "layer"
+            ]
+            default_style.update(color=scolors.primary)
             default_hover_style = json.loads(
                 (ss.JSON_DIR / "layer_hover.json").read_text()
             )
-            default_hover_style.update(color=color.primary)
+            default_hover_style.update(color=scolors.primary)
 
             # apply the style depending on the parameters
             layer.style = layer.style or default_style
             hover_style = default_hover_style if hover else layer.hover_style
             layer.hover_style = layer.hover_style or hover_style
 
-        super().add_layer(layer)
+        super().add(layer)
 
         return
 
@@ -859,6 +877,28 @@ class SepalMap(ipl.Map):
 
         return layer
 
+    def add_legend(
+        self,
+        title=ms.mapping.legend,
+        legend_dict={},
+        position="bottomright",
+        vertical=True,
+    ):
+        """
+        Creates and adds a custom legend as widget control to the map
+
+        Args:
+            title (str, optional): Title of the legend. Defaults to 'Legend'.
+            legend_dict (dict): dictionary with key as label name and value as color
+        """
+
+        # Define as class member so it can be accessed from outside.
+        self.legend = LegendControl(
+            legend_dict, title=title, vertical=vertical, position=position
+        )
+
+        return self.add(self.legend)
+
     # ##########################################################################
     # ###                overwrite geemap calls                              ###
     # ##########################################################################
