@@ -12,6 +12,7 @@ from traitlets import Any, Bool, Dict, Int
 
 from sepal_ui.message import ms
 from sepal_ui.model import Model
+from sepal_ui.scripts import decorator as sd
 from sepal_ui.scripts import gee
 from sepal_ui.scripts import utils as su
 
@@ -102,7 +103,7 @@ class ReclassifyModel(Model):
         gee=False,
         dst_dir=Path.home(),
         aoi_model=None,
-        folder=None,
+        folder="",
         save=True,
         enforce_aoi=False,
         **kwargs,
@@ -122,7 +123,7 @@ class ReclassifyModel(Model):
             su.init_ee()
 
         if self.gee:
-            self.folder = folder or ee.data.getAssetRoots()[0]["id"]
+            self.folder = str(folder) or ee.data.getAssetRoots()[0]["id"]
         else:
             self.folder = None
 
@@ -217,12 +218,12 @@ class ReclassifyModel(Model):
             integer or str
         """
 
-        @su.need_ee
+        @sd.need_ee
         def _ee_image():
 
             return ee.Image(self.src_gee).bandNames().getInfo()
 
-        @su.need_ee
+        @sd.need_ee
         def _ee_vector():
 
             columns = ee.FeatureCollection(self.src_gee).first().getInfo()["properties"]
@@ -256,6 +257,9 @@ class ReclassifyModel(Model):
     def get_aoi(self):
         """Validate and get feature collection from aoi_model"""
 
+        # by default it's none
+        aoi = None
+
         # return None if no aoi_model is selected
         if not self.aoi_model:
             return
@@ -265,8 +269,6 @@ class ReclassifyModel(Model):
         if self.aoi_model.gdf is None:
             if self.enforce_aoi:
                 raise Exception("You have to select an area of interest before")
-            else:
-                aoi = None
 
         else:  # return the aoi as a vector
             if self.gee:
@@ -289,7 +291,7 @@ class ReclassifyModel(Model):
         if not self.band:
             raise Exception("You need to provide a band/property to reclassify.")
 
-        @su.need_ee
+        @sd.need_ee
         def _ee_image():
 
             # reduce the image
@@ -309,7 +311,7 @@ class ReclassifyModel(Model):
 
             return values
 
-        @su.need_ee
+        @sd.need_ee
         def _ee_vector():
 
             collection = ee.FeatureCollection(self.src_gee)
@@ -371,7 +373,7 @@ class ReclassifyModel(Model):
         if not self.band:
             raise Exception("You need to provide a band/property to reclassify.")
 
-        @su.need_ee
+        @sd.need_ee
         def _ee_image():
 
             if not self.src_gee:
@@ -438,7 +440,7 @@ class ReclassifyModel(Model):
 
             return self.dst_gee
 
-        @su.need_ee
+        @sd.need_ee
         def _ee_vector():
 
             if not self.src_gee:
