@@ -1,6 +1,9 @@
+import warnings
 from pathlib import Path
 
 import ipyvuetify as v
+from deprecated.sphinx import deprecated
+from traitlets import Unicode, observe
 
 from sepal_ui.scripts import utils as su
 from sepal_ui.sepalwidgets.sepalwidget import SepalWidget
@@ -14,27 +17,87 @@ class Btn(v.Btn, SepalWidget):
     the color will be defaulted to 'primary' and can be changed afterward according to your need
 
     Args:
+        msg (str, optional): the text to display in the btn
+        gliph (str, optional): the full name of any mdi/fa icon
         text (str, optional): the text to display in the btn
         icon (str, optional): the full name of any mdi/fa icon
         kwargs (dict, optional): any parameters from v.Btn. if set, 'children' will be overwritten.
+
+    .. deprecated:: 2.13
+        ``text`` and ``icon`` will be replaced by ``msg`` and ``gliph`` to avoid duplicating ipyvuetify trait.
+
+    .. deprecated:: 2.14
+        Btn is not using a default ``msg`` anymor`.
     """
 
     v_icon = None
     "v.Icon: the icon in the btn"
 
-    def __init__(self, text="Click", icon="", **kwargs):
+    gliph = Unicode("").tag(sync=True)
+    "traitlet.Unicode: the name of the icon"
+
+    msg = Unicode("").tag(sync=True)
+    "traitlet.Unicode: the text of the btn"
+
+    def __init__(self, msg="", gliph="", **kwargs):
+
+        # deprecation in 2.13 of text and icon
+        # as they already exist in the ipyvuetify Btn traits (as booleans)
+        if "text" in kwargs:
+            if isinstance(kwargs["text"], str):
+                msg = kwargs.pop("text")
+                warnings.warn(
+                    '"text" is deprecated, please use "msg" instead', DeprecationWarning
+                )
+        if "icon" in kwargs:
+            if isinstance(kwargs["icon"], str):
+                gliph = kwargs.pop("icon")
+                warnings.warn(
+                    '"icon" is deprecated, please use "gliph" instead',
+                    DeprecationWarning,
+                )
 
         # create the default v_icon
-        self.v_icon = v.Icon(left=True, children=[""])
-        self.set_icon(icon)
+        self.v_icon = v.Icon(children=[""])
 
         # set the default parameters
         kwargs["color"] = kwargs.pop("color", "primary")
-        kwargs["children"] = [self.v_icon, text]
+        kwargs["children"] = [self.v_icon, self.msg]
 
         # call the constructor
         super().__init__(**kwargs)
 
+        self.gliph = gliph
+        self.msg = msg
+
+    @observe("gliph")
+    def _set_gliph(self, change):
+        """
+        Set a new icon. If the icon is set to "", then it's hidden
+        """
+        new_gliph = change["new"]
+        self.v_icon.children = [new_gliph]
+
+        # hide the component to avoid the right padding
+        if not new_gliph:
+            su.hide_component(self.v_icon)
+        else:
+            su.show_component(self.v_icon)
+
+        return self
+
+    @observe("msg")
+    def _set_text(self, change):
+        """
+        Set the text of the btn
+        """
+
+        self.v_icon.left = bool(change["new"])
+        self.children = [self.v_icon, change["new"]]
+
+        return self
+
+    @deprecated(version="2.14", reason="Replace by the private _set_gliph")
     def set_icon(self, icon=""):
         """
         set a new icon. If the icon is set to "", then it's hidden.
@@ -45,13 +108,7 @@ class Btn(v.Btn, SepalWidget):
         Return:
             self
         """
-        self.v_icon.children = [icon]
-
-        if not icon:
-            su.hide_component(self.v_icon)
-        else:
-            su.show_component(self.v_icon)
-
+        self.gliph = icon
         return self
 
     def toggle_loading(self):
@@ -82,7 +139,7 @@ class DownloadBtn(v.Btn, SepalWidget):
     def __init__(self, text, path="#", **kwargs):
 
         # create a download icon
-        v_icon = v.Icon(left=True, children=["fas fa-download"])
+        v_icon = v.Icon(left=True, children=["fa-solid fa-download"])
 
         # set default parameters
         kwargs["class_"] = kwargs.pop("class_", "ma-2")
