@@ -6,6 +6,7 @@ import ee
 import geopandas as gpd
 import ipyvuetify as v
 import pandas as pd
+from deprecated.sphinx import versionadded
 from ipywidgets import jslink
 from natsort import humansorted
 from traitlets import Any, Bool, Dict, Int, List, Unicode, link, observe
@@ -29,13 +30,18 @@ __all__ = [
 ]
 
 
+@versionadded(
+    version="2.13.0",
+    reason="Empty v_model will be treated as empty string: :code:`v_model=''`.",
+)
 class DatePicker(v.Layout, SepalWidget):
     """
     Custom input widget to provide a reusable DatePicker. It allows to choose date as a string in the following format YYYY-MM-DD
 
     Args:
         label (str, optional): the label of the datepicker field
-        kwargs (optional): any parameter from a v.Layout abject. If set, 'children' will be overwritten.
+        layout_kwargs (dict, optional): any parameter for the wrapper layout
+        kwargs (optional): any parameter from a v.DatePicker abject.
 
     """
 
@@ -48,13 +54,14 @@ class DatePicker(v.Layout, SepalWidget):
     disabled = Bool(False).tag(sync=True)
     "traitlets.Bool: the disabled status of the Datepicker object"
 
-    def __init__(self, label="Date", **kwargs):
+    def __init__(self, label="Date", layout_kwargs={}, **kwargs):
+
+        kwargs["v_model"] = kwargs.get("v_model", "")
 
         # create the widgets
-        date_picker = v.DatePicker(no_title=True, v_model=None, scrollable=True)
+        self.date_picker = v.DatePicker(no_title=True, scrollable=True, **kwargs)
 
         self.date_text = v.TextField(
-            v_model=None,
             label=label,
             hint="YYYY-MM-DD format",
             persistent_hint=True,
@@ -69,7 +76,7 @@ class DatePicker(v.Layout, SepalWidget):
             offset_y=True,
             v_model=False,
             close_on_content_click=False,
-            children=[date_picker],
+            children=[self.date_picker],
             v_slots=[
                 {
                     "name": "activator",
@@ -80,17 +87,18 @@ class DatePicker(v.Layout, SepalWidget):
         )
 
         # set the default parameter
-        kwargs["v_model"] = kwargs.pop("v_model", None)
-        kwargs["row"] = kwargs.pop("row", True)
-        kwargs["class_"] = kwargs.pop("class_", "pa-5")
-        kwargs["align_center"] = kwargs.pop("align_center", True)
-        kwargs["children"] = [v.Flex(xs10=True, children=[self.menu])]
+        layout_kwargs["row"] = layout_kwargs.get("row", True)
+        layout_kwargs["class_"] = layout_kwargs.get("class_", "pa-5")
+        layout_kwargs["align_center"] = layout_kwargs.get("align_center", True)
+        layout_kwargs["children"] = layout_kwargs.pop(
+            "children", [v.Flex(xs10=True, children=[self.menu])]
+        )
 
         # call the constructor
-        super().__init__(**kwargs)
+        super().__init__(**layout_kwargs)
 
-        jslink((date_picker, "v_model"), (self.date_text, "v_model"))
-        jslink((self, "v_model"), (date_picker, "v_model"))
+        link((self.date_picker, "v_model"), (self.date_text, "v_model"))
+        link((self.date_picker, "v_model"), (self, "v_model"))
 
     @observe("v_model")
     def check_date(self, change):
@@ -102,7 +110,7 @@ class DatePicker(v.Layout, SepalWidget):
         self.date_text.error_messages = None
 
         # exit immediately if nothing is set
-        if change["new"] is None:
+        if not change["new"]:
             return
 
         # change the error status
@@ -248,18 +256,25 @@ class FileInput(v.Flex, SepalWidget):
                     "name": "activator",
                     "variable": "x",
                     "children": Btn(
-                        icon="fas fa-search", v_model=False, v_on="x.on", text=label
+                        gliph="fa-solid fa-search",
+                        v_model=False,
+                        v_on="x.on",
+                        msg=label,
                     ),
                 }
             ],
         )
 
         self.reload = v.Btn(
-            icon=True, color="primary", children=[v.Icon(children=["fas fa-sync-alt"])]
+            icon=True,
+            color="primary",
+            children=[v.Icon(children=["fa-solid fa-sync-alt"])],
         )
 
         self.clear = v.Btn(
-            icon=True, color="primary", children=[v.Icon(children=["fas fa-times"])]
+            icon=True,
+            color="primary",
+            children=[v.Icon(children=["fa-solid fa-times"])],
         )
         if not clearable:
             su.hide_component(self.clear)
@@ -658,23 +673,24 @@ class AssetSelect(v.Combobox, SepalWidget):
     def __init__(
         self,
         label=ms.widgets.asset_select.label,
-        folder=None,
+        folder="",
         types=["IMAGE", "TABLE"],
+        default_asset=[],
         **kwargs,
     ):
         self.valid = False
         self.asset_info = None
 
         # if folder is not set use the root one
-        self.folder = folder if folder else ee.data.getAssetRoots()[0]["id"]
+        self.folder = str(folder) or ee.data.getAssetRoots()[0]["id"]
         self.types = types
 
+        # load the default assets
+        self.default_asset = default_asset
+
         # Validate the input as soon as the object is instantiated
         self.observe(self._validate, "v_model")
 
-        # load the assets in the combobox
-        self._get_items()
-
         # set the default parameters
         kwargs["v_model"] = kwargs.pop("v_model", None)
         kwargs["clearable"] = kwargs.pop("clearable", True)
@@ -688,48 +704,17 @@ class AssetSelect(v.Combobox, SepalWidget):
         # create the widget
         super().__init__(**kwargs)
 
+        # load the assets in the combobox
+        self._get_items()
+
         # add js behaviours
         self.on_event("click:prepend", self._get_items)
-
-    @observe("default_asset")
-    def _add_default(self, change=None):
-        """Add default element(s) to item list"""
-
-        new_val = change["new"]
-
-        if new_val:
-
-            new_items = self.items.copy()
-
-            if isinstance(new_val, str):
-                new_val = [new_val]
-
-            self.v_model = new_val[0]
-
-            default_items = [
-                {"divider": True},
-                {"header": ms.widgets.asset_select.custom},
-            ] + [default for default in new_val]
-
-            # Check if there are previously custom items and replace them, instead
-            # of append them
-
-            if {"header": ms.widgets.asset_select.custom} in self.items:
-
-                next_div_index = new_items.index({"divider": True}, 1)
-                new_items[0:next_div_index] = default_items
-
-            else:
-                new_items = default_items + self.items
-
-            self.items = new_items
-
-        return
+        self.observe(self._get_items, "default_asset")
 
     @su.switch("loading")
     def _validate(self, change):
         """
-        Validate the selected access. Throw an error message if is not accesible or not in the type list.
+        Validate the selected asset. Throw an error message if is not accesible or not in the type list.
         """
 
         self.error_messages = None
@@ -758,15 +743,29 @@ class AssetSelect(v.Combobox, SepalWidget):
     @su.switch("loading", "disabled")
     def _get_items(self, *args):
 
+        # init the item list
+        items = []
+
+        # add the default values if needed
+        if self.default_asset:
+
+            if isinstance(self.default_asset, str):
+                self.default_asset = [self.default_asset]
+
+            self.v_model = self.default_asset[0]
+
+            header = ms.widgets.asset_select.custom
+            items += [{"divider": True}, {"header": header}]
+            items += [default for default in self.default_asset]
+
         # get the list of user asset
         raw_assets = gee.get_assets(self.folder)
-
         assets = {
             k: sorted([e["id"] for e in raw_assets if e["type"] == k])
             for k in self.types
         }
 
-        items = []
+        # sort the assets by types
         for k in self.types:
             if len(assets[k]):
                 items += [
