@@ -1,8 +1,7 @@
 import ipyvuetify as v
 from deprecated.sphinx import versionadded
-from ipywidgets import link
 from markdown import markdown
-from traitlets import Any, Unicode, dlink, observe
+from traitlets import Any, Unicode, link, observe
 
 from sepal_ui import color
 from sepal_ui.sepalwidgets.sepalwidget import SepalWidget, Tooltip
@@ -67,7 +66,7 @@ class CopyToClip(v.VuetifyTemplate):
         kwargs["outlined"] = kwargs.pop("outlined", True)
         kwargs["label"] = kwargs.pop("label", "Copy To clipboard")
         kwargs["readonly"] = kwargs.pop("readonly", True)
-        kwargs["append_icon"] = kwargs.pop("append_icon", "fas fa-clipboard")
+        kwargs["append_icon"] = kwargs.pop("append_icon", "fa-solid fa-clipboard")
         kwargs["v_model"] = kwargs.pop("v_model", None)
         kwargs["class_"] = kwargs.pop("class_", "ma-5")
 
@@ -103,7 +102,7 @@ class CopyToClip(v.VuetifyTemplate):
 
     def _clip(self, widget, event, data):
         self.send({"method": "clip", "args": [self.tf.v_model]})
-        self.tf.append_icon = "fas fa-clipboard-check"
+        self.tf.append_icon = "fa-solid fa-clipboard-check"
 
         return
 
@@ -119,7 +118,7 @@ class StateIcon(Tooltip):
         kwargs: Any arguments from a v.Tooltip
     """
 
-    value = Any().tag(sync=True)
+    values = Any().tag(sync=True)
     "bool, str, int: key name of the current state of component. Values must be same as states_dict keys."
 
     states = None
@@ -128,7 +127,7 @@ class StateIcon(Tooltip):
     icon = None
     "v.Icon: the colored Icon of the tooltip"
 
-    def __init__(self, model, model_trait, states=None, **kwargs):
+    def __init__(self, model=None, model_trait=None, states=None, **kwargs):
 
         # set the default parameter of the tooltip
         kwargs["right"] = kwargs.pop("right", True)
@@ -143,14 +142,17 @@ class StateIcon(Tooltip):
         # Get the first value (states first key) to use as default one
         init_value = self.states[next(iter(self.states))]
 
-        self.icon = v.Icon(children=["fas fa-circle"], color=init_value[1], small=True)
+        self.icon = v.Icon(
+            children=["fa-solid fa-circle"], color=init_value[1], small=True
+        )
 
         super().__init__(self.icon, init_value[0], **kwargs)
 
         # Directional from there to link here.
-        dlink((model, model_trait), (self, "value"))
+        if all([model, model_trait]):
+            link((model, model_trait), (self, "values"))
 
-    @observe("value")
+    @observe("values")
     def _swap(self, change):
         """Swap between states"""
 
