@@ -1,4 +1,5 @@
 from ipyleaflet import WidgetControl
+
 from sepal_ui import mapping as sm
 from sepal_ui import sepalwidgets as sw
 
@@ -20,26 +21,26 @@ class MapTile(sw.Tile):
     def set_code(self, link):
         "add the code link btn to the map"
 
-        btn = sm.MapBtn("fas fa-code", href=link, target="_blank")
+        btn = sm.MapBtn("fa-solid fa-code", href=link, target="_blank")
         control = WidgetControl(widget=btn, position="bottomleft")
-        self.m.add_control(control)
+        self.m.add(control)
 
         return
 
     def set_wiki(self, link):
         "add the wiki link btn to the map"
 
-        btn = sm.MapBtn("fas fa-book-open", href=link, target="_blank")
+        btn = sm.MapBtn("fa-solid fa-book-open", href=link, target="_blank")
         control = WidgetControl(widget=btn, position="bottomleft")
-        self.m.add_control(control)
+        self.m.add(control)
 
         return
 
     def set_issue(self, link):
         "add the code link btn to the map"
 
-        btn = sm.MapBtn("fas fa-bug", href=link, target="_blank")
+        btn = sm.MapBtn("fa-solid fa-bug", href=link, target="_blank")
         control = WidgetControl(widget=btn, position="bottomleft")
-        self.m.add_control(control)
+        self.m.add(control)
 
         return
